@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import List
+from typing import Any, Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -23,10 +23,15 @@ else:
 __all__ = (
     "BatchGetRecordErrorTypeDef",
     "BatchGetRecordIdentifierTypeDef",
-    "BatchGetRecordResponseTypeDef",
+    "BatchGetRecordRequestTypeDef",
+    "BatchGetRecordResponseResponseTypeDef",
     "BatchGetRecordResultDetailTypeDef",
+    "DeleteRecordRequestTypeDef",
     "FeatureValueTypeDef",
-    "GetRecordResponseTypeDef",
+    "GetRecordRequestTypeDef",
+    "GetRecordResponseResponseTypeDef",
+    "PutRecordRequestTypeDef",
+    "ResponseMetadataTypeDef",
 )
 
 BatchGetRecordErrorTypeDef = TypedDict(
@@ -61,12 +66,20 @@ class BatchGetRecordIdentifierTypeDef(
     pass
 
 
-BatchGetRecordResponseTypeDef = TypedDict(
-    "BatchGetRecordResponseTypeDef",
+BatchGetRecordRequestTypeDef = TypedDict(
+    "BatchGetRecordRequestTypeDef",
+    {
+        "Identifiers": List["BatchGetRecordIdentifierTypeDef"],
+    },
+)
+
+BatchGetRecordResponseResponseTypeDef = TypedDict(
+    "BatchGetRecordResponseResponseTypeDef",
     {
         "Records": List["BatchGetRecordResultDetailTypeDef"],
         "Errors": List["BatchGetRecordErrorTypeDef"],
         "UnprocessedIdentifiers": List["BatchGetRecordIdentifierTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -79,6 +92,15 @@ BatchGetRecordResultDetailTypeDef = TypedDict(
     },
 )
 
+DeleteRecordRequestTypeDef = TypedDict(
+    "DeleteRecordRequestTypeDef",
+    {
+        "FeatureGroupName": str,
+        "RecordIdentifierValueAsString": str,
+        "EventTime": str,
+    },
+)
+
 FeatureValueTypeDef = TypedDict(
     "FeatureValueTypeDef",
     {
@@ -87,10 +109,49 @@ FeatureValueTypeDef = TypedDict(
     },
 )
 
-GetRecordResponseTypeDef = TypedDict(
-    "GetRecordResponseTypeDef",
+_RequiredGetRecordRequestTypeDef = TypedDict(
+    "_RequiredGetRecordRequestTypeDef",
     {
-        "Record": List["FeatureValueTypeDef"],
+        "FeatureGroupName": str,
+        "RecordIdentifierValueAsString": str,
+    },
+)
+_OptionalGetRecordRequestTypeDef = TypedDict(
+    "_OptionalGetRecordRequestTypeDef",
+    {
+        "FeatureNames": List[str],
     },
     total=False,
 )
+
+
+class GetRecordRequestTypeDef(_RequiredGetRecordRequestTypeDef, _OptionalGetRecordRequestTypeDef):
+    pass
+
+
+GetRecordResponseResponseTypeDef = TypedDict(
+    "GetRecordResponseResponseTypeDef",
+    {
+        "Record": List["FeatureValueTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+PutRecordRequestTypeDef = TypedDict(
+    "PutRecordRequestTypeDef",
+    {
+        "FeatureGroupName": str,
+        "Record": List["FeatureValueTypeDef"],
+    },
+)
+
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
